%global srcname pyopencl
%global bname opencl

# It is hard to run tests
%bcond_with tests

Name:           python-%{bname}
Version:        2025.1
Release:        %mkrel 4
Summary:        Python wrapper for OpenCL
Group:          Development/Python

# https://bugzilla.redhat.com/show_bug.cgi?id=1219819#c16
# Boost (boost):
# pyopencl/cl/pyopencl-bessel-j.cl
# pyopencl/cl/pyopencl-bessel-y.cl
# pyopencl/cl/pyopencl-eval-tbl.cl
# GPLv2 (cephes):
# pyopencl/cl/pyopencl-airy.cl
# ASL 2.0 (ranluxcl), will be removed in 2018.x:
# pyopencl/cl/pyopencl-ranluxcl.cl
# ASL 2.0:
# pyopencl/scan.py
# BSD (random123):
# pyopencl/cl/pyopencl-random123/array.h
# pyopencl/cl/pyopencl-random123/openclfeatures.h
# pyopencl/cl/pyopencl-random123/philox.cl
# pyopencl/cl/pyopencl-random123/threefry.cl
# BSD:
# pyopencl/bitonic_sort.py
# pyopencl/bitonic_sort_templates.py

License:        MIT and Boost and ASL 2.0 and GPLv2 and BSD
URL:            https://mathema.tician.de/software/pyopencl
Source0:        %{pypi_source}
Patch0:         pyopencl-linking.patch

# pyopencl/cl/pyopencl-bessel-[j,y].cl and
# pyopencl/cl/pyopencl-eval-tbl.cl contain snippets taken from boost
# and cephes. pyopencl/cl/pyopencl-airy.cl contains code taken from
# cephes.
Provides:       bundled(boost-math)
Provides:       bundled(cephes) = 2.8
# pyopencl/cl/pyopencl-ranluxcl.cl contains a modified version of the
# ranluxcl library
Provides:       bundled(ranluxcl) = 1.3.1
# ./pyopencl/compyte/*
Provides:       bundled(compyte)

BuildRequires:  gcc-c++
BuildRequires:  blas-devel
BuildRequires:  boost-devel
BuildRequires:  cmake(nanobind)
BuildRequires:  cmake(OpenCLHeaders)
BuildRequires:  pkgconfig(ocl-icd)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pybind11-devel

%if %{with tests}
BuildRequires:  pocl
%endif

%description
PyOpenCL makes it possible to access GPUs and other massively
parallel compute devices from Python. Specifically, PyOpenCL
provides Pythonic access to the OpenCL parallel computation
API in a manner similar to the sister project `PyCUDA`.

%package -n python3-%{bname}
Summary:        Python 3 wrapper for OpenCL
Group:          Development/Python
%{?python_provide:%python_provide python3-%{bname}}
%{?python_provide:%python_provide python3-%{srcname}}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-numpy-devel
BuildRequires:  python3dist(pybind11)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(scikit-build-core)
Recommends:     python3dist(Mako)
%if %{with tests}
BuildRequires:  python3-pytest
BuildRequires:  python3-pytools >= 2017.2
BuildRequires:  python3-decorator
BuildRequires:  python3-appdirs
BuildRequires:  python3-six
BuildRequires:  python3-scipy
%endif

%description -n python3-%{bname}
PyOpenCL makes it possible to access GPUs and other massively
parallel compute devices from Python. Specifically, PyOpenCL
provides Pythonic access to the OpenCL parallel computation
API in a manner similar to the sister project `PyCUDA`.

Python 3 version of %{srcname}.

%prep
%autosetup -n %{srcname}-%{version} -p1

rm -vf examples/download-examples-from-wiki.py


# generate html docs
#sphinx-build doc/source html
# remove the sphinx-build leftovers
#rm -rf html/.{doctrees,buildinfo}

%build
%pyproject_wheel -C"cmake.build-type=RelWithDebInfo"

%install
%pyproject_install
%pyproject_save_files %{srcname}

find %{buildroot}%{python3_sitearch}/%{srcname} -name '*.so' -exec chmod 755 {} \+

%if %{with tests}
%check
pushd test/
  export PYTHONPATH=%{buildroot}%{python3_sitearch}
  find -name '*.py' -exec py.test-%{python3_version} -v {} \+
popd
%endif

%files -n python3-%{bname} -f %{pyproject_files}
%license LICENSE
%doc examples


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 2025.1-4.mga10
+ Revision: 2241132
- Mageia 10 Mass Rebuild

* Sun Mar 02 2025 wally <wally> 2025.1-3.mga10
+ Revision: 2158443
- rebuild for python3.13

* Sun Feb 02 2025 daviddavid <daviddavid> 2025.1-2.mga10
+ Revision: 2144850
- fix linking issue

* Sun Feb 02 2025 daviddavid <daviddavid> 2025.1-1.mga10
+ Revision: 2144635
- new version: 2025.1

* Fri Feb 23 2024 daviddavid <daviddavid> 2024.1-1.mga10
+ Revision: 2043475
- new version: 2024.1
+ tv <tv>
- Rebuild for python-3.12

* Tue Jan 31 2023 daviddavid <daviddavid> 2019.1.2-6.mga9
+ Revision: 1937227
- rebuild for new opencl-headers api 3.0
- update some descriptions

* Mon Apr 04 2022 umeabot <umeabot> 2019.1.2-5.mga9
+ Revision: 1842990
- Mageia 9 Mass Rebuild

* Wed Feb 23 2022 mrambo3501 <mrambo3501> 2019.1.2-4.mga9
+ Revision: 1783591
- rebuild for python-3.10
- delete unneeded BR libatlas-devel which conflicts with blas-devel

* Tue Apr 20 2021 daviddavid <daviddavid> 2019.1.2-3.mga9
+ Revision: 1717247
- rebuild for python 3.9

* Sat Feb 29 2020 daviddavid <daviddavid> 2019.1.2-2.mga8
+ Revision: 1552269
- compile with python3-mako
- new version: 2019.1.2

* Sun Feb 16 2020 umeabot <umeabot> 2018.2.2-3.mga8
+ Revision: 1533894
- Mageia 8 Mass Rebuild

* Tue Sep 24 2019 tv <tv> 2018.2.2-2.mga8
+ Revision: 1445512
- rebuild for python-3.8
- drop python2 subpkg

* Wed Jan 09 2019 shlomif <shlomif> 2018.2.2-1.mga7
+ Revision: 1353517
- Rebuild for python3 3.7

* Sun Sep 30 2018 joequant <joequant> 2018.2-1.mga7
+ Revision: 1312624
- add numpy devel
- move pybind11
- fix build requires
- add pybind11
- add group and libatlas
- update to 2018.2

* Sun Sep 23 2018 umeabot <umeabot> 2013.1-15.mga7
+ Revision: 1300539
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 2013.1-14.mga7
+ Revision: 1184766
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 2013.1-13.mga7
+ Revision: 1178346
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 2013.1-12.mga7
+ Revision: 1154548
- rebuild with latest boost

* Sun Dec 27 2015 daviddavid <daviddavid> 2013.1-11.mga6
+ Revision: 916062
- rebuild for new boost 1.60.0
- use new python macros

* Sun Sep 27 2015 tv <tv> 2013.1-10.mga6
+ Revision: 884220
- rebuild for new boost

* Sun Aug 02 2015 daviddavid <daviddavid> 2013.1-9.mga6
+ Revision: 860610
- rebuild for new boost-1.58.0

* Wed Oct 15 2014 umeabot <umeabot> 2013.1-8.mga5
+ Revision: 751105
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2013.1-7.mga5
+ Revision: 729220
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2013.1-6.mga5
+ Revision: 688191
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Sat Feb 08 2014 barjac <barjac> 2013.1-4.mga5
+ Revision: 586755
- rebuild against boost-1.55

* Tue Oct 22 2013 umeabot <umeabot> 2013.1-3.mga4
+ Revision: 543906
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2013.1-2.mga4
+ Revision: 499008
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Jul 27 2013 joequant <joequant> 2013.1-1.mga4
+ Revision: 459146
- build spec fixes
- remove python-opencl requires
- add gl dependency
- add python-numpy-devel
- imported package python-opencl

